@@ -11,12 +11,7 @@
 #include <QDialog>
 
 #ifdef HAVE_PIMTEXTEDIT
-#include <KPIMTextEdit/RichTextEditorWidget>
-
-namespace KPIMTextEdit
-{
-class RichTextEditorWidget;
-}
+#include <TextCustomEditor/RichTextEditorWidget>
 #else
 
 class QTextEdit;
@@ -24,8 +19,7 @@ class QTextEdit;
 
 namespace Kleo
 {
-namespace Private
-{
+class AuditLogEntry;
 
 class KLEO_EXPORT AuditLogViewer : public QDialog
 {
@@ -35,6 +29,8 @@ public:
 
     ~AuditLogViewer() override;
 
+    static void showAuditLog(QWidget *parent, const AuditLogEntry &auditLog, const QString &title = {});
+
     void setAuditLog(const QString &log);
 
 private Q_SLOTS:
@@ -47,11 +43,10 @@ private:
 
     QString m_log;
 #ifdef HAVE_PIMTEXTEDIT
-    KPIMTextEdit::RichTextEditorWidget *m_textEdit = nullptr;
+    TextCustomEditor::RichTextEditorWidget *m_textEdit = nullptr;
 #else
     QTextEdit *m_textEdit = nullptr;
 #endif
 };
 
 }
-}
